powered by
Aborts with an informative error if the number of factor levels exceeds the number of colors available in the specified palette.
.is_palette_sufficient(palette, min_length)
ggstatsplot:::.is_palette_sufficient("ggthemes::gdoc", 6L) try(ggstatsplot:::.is_palette_sufficient("ggthemes::gdoc", 30L))
Run the code above in your browser using DataLab